biom.table.Table.dtype — biom-format.org

# biom-format.org

## biom.table.Table.dtype

« biom.table.Table :: Contents :: biom.table.Table.matrix_data »

# biom.table.Table.dtype

`Table.` `dtype`

  The type of the objects in the underlying contingency matrix

« biom.table.Table :: Contents :: biom.table.Table.matrix_data »

© Copyright 2011-2013, The BIOM Format Development Team. Last updated on Nov 19, 2014. Created using Sphinx 1.2.3.